@@ -18,6 +18,7 @@ static void addNewIp(FFlist* list, const char* name, const char* addr, int type,
         ffStrbufInit(&ip->ipv6);
         ffStrbufInit(&ip->mac);
         ip->defaultRoute = defaultRoute;
+        ip->speed = -1;
         ip->mtu = -1;
     }
     else
@@ -150,7 +151,13 @@ const char* ffDetectLocalIps(const FFLocalIpOptions* options, FFlist* results)
         }
 
         if (!newIp)
-            FF_LIST_GET(FFLocalIpResult, *results, results->length - 1)->mtu = (int32_t) adapter->Mtu;
+        {
+            FFLocalIpResult* result = FF_LIST_GET(FFLocalIpResult, *results, results->length - 1);
+            if (options->showType & FF_LOCALIP_TYPE_SPEED_BIT)
+                result->speed = (int32_t) (adapter->ReceiveLinkSpeed / 1000);
+            if (options->showType & FF_LOCALIP_TYPE_MTU_BIT)
+                result->mtu = (int32_t) adapter->Mtu;
+        }
     }
 
     return NULL;
