@@ -12,6 +12,8 @@ typedef enum FFLocalIpType
     FF_LOCALIP_TYPE_IPV6_BIT        = 1 << 2,
     FF_LOCALIP_TYPE_MAC_BIT         = 1 << 3,
     FF_LOCALIP_TYPE_PREFIX_LEN_BIT  = 1 << 4,
+    FF_LOCALIP_TYPE_MTU_BIT  = 1 << 5,
+    FF_LOCALIP_TYPE_SPEED_BIT  = 1 << 6,
 
     FF_LOCALIP_TYPE_COMPACT_BIT            = 1 << 10,
     FF_LOCALIP_TYPE_DEFAULT_ROUTE_ONLY_BIT = 1 << 11,
